@@ -1,7 +1,7 @@
 package Pod::Weaver::Section::Completion::PerinciCmdLine;
 
-our $DATE = '2015-08-26'; # DATE
-our $VERSION = '0.13'; # VERSION
+our $DATE = '2016-04-30'; # DATE
+our $VERSION = '0.14'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -29,6 +29,13 @@ sub weave_section {
 
     (my $command_name = $filename) =~ s!.+/!!;
 
+    # file looks like a completer script, don't bother generating completer for
+    # completer :)
+    if ($command_name =~ /\A_/) {
+        $self->log_debug(["skipped script %s (a completer itself)", $filename]);
+        return;
+    }
+
     my $text;
     if ($res->[3]{'func.is_inline'}) {
         $text = $self->section_text_has_completion({command_name=>$command_name});
@@ -55,7 +62,7 @@ Pod::Weaver::Section::Completion::PerinciCmdLine - Add a COMPLETION section for
 
 =head1 VERSION
 
-This document describes version 0.13 of Pod::Weaver::Section::Completion::PerinciCmdLine (from Perl distribution Pod-Weaver-Section-Completion-PerinciCmdLine), released on 2015-08-26.
+This document describes version 0.14 of Pod::Weaver::Section::Completion::PerinciCmdLine (from Perl distribution Pod-Weaver-Section-Completion-PerinciCmdLine), released on 2016-04-30.
 
 =head1 SYNOPSIS
 
@@ -71,10 +78,6 @@ completion for the scripts.
 
 =for Pod::Coverage weave_section
 
-=head1 SEE ALSO
-
-L<Perinci::CmdLine>
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Pod-Weaver-Section-Completion-PerinciCmdLine>.
@@ -91,13 +94,17 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Perinci::CmdLine>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
